@@ -9,15 +9,13 @@ use warnings;
 my %store;
 
 sub get_session_data {
-    my ( $c, @keys ) = @_;
-    @store{@keys};
+    my ( $c, $sid ) = @_;
+    $store{$sid};
 }
 
 sub store_session_data {
-    my $c = shift;
-    my %data = @_;
-
-    @store{ keys %data } = values %data;
+    my ( $c, $sid, $data ) = @_;
+    $store{$sid} = $data;
 }
 
 sub delete_session_data {
